@@ -15,6 +15,16 @@ class Booking(MutexEvent):
     room = models.ForeignKey(Room)
     deleted_at = models.DateTimeField(blank=True, null=True)
 
+    class MutexMeta:
+        collision_fields = ['room']
+        exclude = Q(room__can_parallel=True) | Q(deleted_at__isnull=False)
+
+
+class RequestedBooking(MutexEvent):
+    request = models.CharField(max_length=100, default='room')
+    room = models.ForeignKey(Room, blank=True, null=True)
+    deleted_at = models.DateTimeField(blank=True, null=True)
+
     class MutexMeta:
         collision_fields = ['room']
         exclude = Q(room__can_parallel=True) | Q(deleted_at__isnull=False)
\ No newline at end of file
